@@ -2,10 +2,10 @@ package WebService::Google::Reader;
 
 use strict;
 use warnings;
-use base qw( Class::Accessor::Fast );
+use base qw(Class::Accessor::Fast);
 
 use HTTP::Cookies;
-use HTTP::Request::Common qw( GET POST );
+use HTTP::Request::Common qw(GET POST);
 use LWP::UserAgent;
 use JSON::Any;
 use URI::Escape;
@@ -15,11 +15,11 @@ use WebService::Google::Reader::Constants;
 use WebService::Google::Reader::Feed;
 use WebService::Google::Reader::ListElement;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
-if ( DEBUG ) {
+if (DEBUG) {
     require Carp;
-    @SIG{qw( __DIE__ __WARN__ )} = \( &Carp::confess, &Carp::cluck );
+    @SIG{qw(__DIE__ __WARN__)} = \(&Carp::confess, &Carp::cluck);
 }
 
 __PACKAGE__->mk_accessors(qw(
@@ -32,19 +32,19 @@ sub new {
     my $self = bless \%params, $class;
 
     my $ua = $params{ua};
-    unless ( ref $ua and $ua->isa( q(LWP::UserAgent) ) ) {
+    unless (ref $ua and $ua->isa(q(LWP::UserAgent))) {
         $ua = LWP::UserAgent->new(
             # Google only compresses content for certain agents or if gzip
             # is part of the agent name.
-            agent => __PACKAGE__.'/'.$VERSION . ( HAS_ZLIB ? ' (gzip)' :'' )
+            agent => __PACKAGE__.'/'.$VERSION . (HAS_ZLIB ? ' (gzip)' :'')
         );
-        $self->ua( $ua );
+        $self->ua($ua);
     }
-    unless ( $ua->cookie_jar ) {
-        $ua->cookie_jar( HTTP::Cookies->new( hide_cookie2 => 1 ) );
+    unless ($ua->cookie_jar) {
+        $ua->cookie_jar(HTTP::Cookies->new(hide_cookie2 => 1));
     }
 
-    $self->scheme( $params{secure} || $params{https} ? 'https' : 'http' );
+    $self->scheme($params{secure} || $params{https} ? 'https' : 'http');
 
     return $self;
 }
@@ -52,27 +52,27 @@ sub new {
 ## Feeds
 
 sub feed {
-    return shift->_feed( feed => shift, @_ );
+    return shift->_feed(feed => shift, @_);
 }
 
 sub tag {
-    return shift->_feed( tag => shift, @_ );
+    return shift->_feed(tag => shift, @_);
 }
 
 sub state {
-    return shift->_feed( state => shift, @_ );
+    return shift->_feed(state => shift, @_);
 }
 
 sub shared {
-    return shift->state( 'broadcast', @_ );
+    return shift->state('broadcast', @_);
 }
 
 sub starred {
-    return shift->state( 'starred', @_ );
+    return shift->state('starred', @_);
 }
 
 sub unread {
-    return shift->state( 'reading-list', exclude => { state => 'read' }, @_ );
+    return shift->state('reading-list', exclude => { state => 'read' }, @_);
 }
 
 sub search {
@@ -81,64 +81,64 @@ sub search {
     $self->_login or return;
     $self->_token or return;
 
-    my $uri = URI->new( SEARCH_IDS_URL );
+    my $uri = URI->new(SEARCH_IDS_URL);
 
     my %fields;
     $fields{num} = $params{results} || 1000;
 
-    my @types = grep { exists $params{ $_ } } qw( feed state tag );
+    my @types = grep { exists $params{$_} } qw(feed state tag);
     for my $type (@types) {
-        push @{ $fields{s} }, _encode_type( $type, $params{$type} );
+        push @{$fields{s}}, _encode_type($type, $params{$type});
     }
 
-    $uri->query_form( { q => $query, %fields, output => 'json' } );
+    $uri->query_form({ q => $query, %fields, output => 'json' });
 
-    my $req = HTTP::Request->new( GET => $uri );
-    my $res = $self->_request( $req ) or return;
+    my $req = HTTP::Request->new(GET => $uri);
+    my $res = $self->_request($req) or return;
 
     my @ids = do {
-        my $ref = eval { JSON::Any->decode( $res->decoded_content ) };
-        if ( $@ ) {
-            $self->error( "Failed to parse JSON response: $@" );
+        my $ref = eval { JSON::Any->decode($res->decoded_content) };
+        if ($@) {
+            $self->error("Failed to parse JSON response: $@");
             return;
         }
-        map { $_->{id} } @{ $ref->{results} };
+        map { $_->{id} } @{$ref->{results}};
     };
     return unless @ids;
-    if ( my $order = $params{order} || $params{sort} ) {
+    if (my $order = $params{order} || $params{sort}) {
         @ids = reverse @ids if 'asc' eq $order;
     }
 
-    my $feed = ( __PACKAGE__.'::Feed' )->new(
+    my $feed = (__PACKAGE__.'::Feed')->new(
         request => $req, ids => \@ids, count => $params{count} || 40,
     );
-    return $self->more( $feed );
+    return $self->more($feed);
 }
 
 sub more {
     my ($self, $feed) = @_;
 
     my $req;
-    if ( defined $feed->ids ) {
-        my @ids = splice @{ $feed->ids }, 0, $feed->count;
+    if (defined $feed->ids) {
+        my @ids = splice @{$feed->ids}, 0, $feed->count;
         return unless @ids;
 
-        my $uri = URI->new( STREAM_IDS_CONTENT_URL, 'https' );
-        $req = POST( $uri, [ ( map { ('i', $_) } @ids ), T => $self->token ] );
+        my $uri = URI->new(STREAM_IDS_CONTENT_URL, 'https');
+        $req = POST($uri, [ (map { ('i', $_) } @ids), T => $self->token ]);
     }
-    elsif ( $feed->elem ) {
+    elsif ($feed->elem) {
         return unless defined $feed->continuation and $feed->entries;
         $req = $feed->request;
-        $req->uri->query_param( c => $feed->continuation );
+        $req->uri->query_param(c => $feed->continuation);
     }
-    elsif ( $req = $feed->request ) {
+    elsif ($req = $feed->request) {
         # Initial request.
     }
     else { return }
 
-    my $res = $self->_request( $req ) or return;
+    my $res = $self->_request($req) or return;
 
-    $feed->init( Stream => $res->decoded_content( ref => 1 ) ) or return;
+    $feed->init(Stream => $res->decoded_content(ref => 1)) or return;
     return $feed;
 }
 
@@ -147,62 +147,62 @@ sub more {
 ## Lists
 
 sub tags {
-    return $_[0]->_list( LIST_TAGS_URL );
+    return $_[0]->_list(LIST_TAGS_URL);
 }
 
 sub feeds {
-    return $_[0]->_list( LIST_SUBS_URL );
+    return $_[0]->_list(LIST_SUBS_URL);
 }
 
 sub preferences {
-    return $_[0]->_list( LIST_PREFS_URL );
+    return $_[0]->_list(LIST_PREFS_URL);
 }
 
 sub counts {
-    return $_[0]->_list( LIST_COUNTS_URL );
+    return $_[0]->_list(LIST_COUNTS_URL);
 }
 
 sub userinfo {
     my ($self) = @_;
-    return $_[0]->_list( LIST_USER_INFO_URL );
+    return $_[0]->_list(LIST_USER_INFO_URL);
 }
 
 ## Edit tags
 
 sub edit_tag  {
-    return shift->_edit_tag( tag => @_ );
+    return shift->_edit_tag(tag => @_);
 }
 
 sub edit_state {
-    return shift->_edit_tag( state => @_ );
+    return shift->_edit_tag(state => @_);
 }
 
 sub share_tag {
-    return shift->edit_tag( \@_, share => 1 );
+    return shift->edit_tag(\@_, share => 1);
 }
 
 sub unshare_tag {
-    return shift->edit_tag( \@_, unshare => 1 );
+    return shift->edit_tag(\@_, unshare => 1);
 }
 
 sub share_state {
-    return shift->edit_state( \@_, share => 1 );
+    return shift->edit_state(\@_, share => 1);
 }
 
 sub unshare_state {
-    return shift->edit_state( \@_, unshare => 1 );
+    return shift->edit_state(\@_, unshare => 1);
 }
 
 sub delete_tag {
-    return shift->edit_tag( \@_, delete => 1 );
+    return shift->edit_tag(\@_, delete => 1);
 }
 
 sub mark_read_tag {
-    return shift->mark_read( tag => \@_ );
+    return shift->mark_read(tag => \@_);
 }
 
 sub mark_read_state {
-    return shift->mark_read( state => \@_ );
+    return shift->mark_read(state => \@_);
 }
 
 sub rename_feed_tag {
@@ -213,10 +213,10 @@ sub rename_feed_tag {
 
     # Get the list of subs which are associated with the tag to be renamed.
     FEED:
-    for my $feed ( @feeds ) {
-        for my $cat ( $self->categories ) {
-            for my $o ( 'ARRAY' eq ref $old ? @$old : ( $old ) ) {
-                if ( $old eq $cat->label or $old eq $cat->id ) {
+    for my $feed (@feeds) {
+        for my $cat ($self->categories) {
+            for my $o ('ARRAY' eq ref $old ? @$old : ($old)) {
+                if ($old eq $cat->label or $old eq $cat->id) {
                     push @tagged, $feed->id;
                     next FEED;
                 }
@@ -224,20 +224,20 @@ sub rename_feed_tag {
         }
     }
 
-    $_ = [ _encode_type( tag => $_) ] for ( $old, $new );
+    $_ = [ _encode_type(tag => $_) ] for ($old, $new);
 
-    return $self->edit_feed( \@tagged, tag => $new, untag => $old );
+    return $self->edit_feed(\@tagged, tag => $new, untag => $old);
 }
 
 sub rename_entry_tag {
     my ($self, $old, $new) = @_;
 
-    for my $o ( 'ARRAY' eq ref $old ? @$old : ( $old ) ) {
-        my $feed = $self->tag( $o ) or return;
+    for my $o ('ARRAY' eq ref $old ? @$old : ($old)) {
+        my $feed = $self->tag($o) or return;
         do {
-            $self->edit_entry( [ $feed->entries ], tag => $new, untag => $old )
+            $self->edit_entry([ $feed->entries ], tag => $new, untag => $old)
                 or return;
-        } while ( $self->feed( $feed ) );
+        } while ($self->feed($feed));
     }
 
     return 1;
@@ -245,9 +245,9 @@ sub rename_entry_tag {
 
 sub rename_tag {
     my $self = shift;
-    return unless $self->rename_tag_feed( @_ );
-    return unless $self->rename_tag_entry( @_ );
-    return $self->delete_tags( shift );
+    return unless $self->rename_tag_feed(@_);
+    return unless $self->rename_tag_entry(@_);
+    return $self->delete_tags(shift);
 }
 
 ## Edit feeds
@@ -261,27 +261,27 @@ sub edit_feed {
     my $url = EDIT_SUB_URL;
 
     my %fields;
-    for my $s ( 'ARRAY' eq ref $sub ? @$sub : ( $sub ) ) {
-        if ( __PACKAGE__.'::Feed' eq ref $s ) {
+    for my $s ('ARRAY' eq ref $sub ? @$sub : ($sub)) {
+        if (__PACKAGE__.'::Feed' eq ref $s) {
             my $id = $s->id or next;
             $id =~ s[^tag:google.com,2005:reader/][];
             $id =~ s[\?.*][];
-            push @{ $fields{s} }, $id;
+            push @{$fields{s}}, $id;
         }
         else {
-            push @{ $fields{s} }, _encode_type( feed => $s );
+            push @{$fields{s}}, _encode_type(feed => $s);
         }
     }
-    return 1 unless @{ $fields{s} || [] };
+    return 1 unless @{$fields{s} || []};
 
-    if ( defined( my $title = $params{title} ) ) {
+    if (defined(my $title = $params{title})) {
         $fields{t} = $title;
     }
 
-    if ( grep { exists $params{ $_ } } qw( subscribe add ) ) {
+    if (grep { exists $params{$_} } qw(subscribe add)) {
         $fields{ac} = 'subscribe';
     }
-    elsif ( grep { exists $params{ $_ } } qw( unsubscribe remove ) ) {
+    elsif (grep { exists $params{$_} } qw(unsubscribe remove)) {
         $fields{ac} = 'unsubscribe';
     }
     else {
@@ -289,55 +289,55 @@ sub edit_feed {
     }
 
     # Add a tag or state.
-    for my $t (qw( tag state )) {
-        next unless exists $params{ $t };
-        defined( my $p = $params{ $t } ) or next;
-        for my $a ( 'ARRAY' eq ref $p ? @$p : ( $p ) ) {
-            push @{ $fields{a} }, _encode_type( $t => $a );
+    for my $t (qw(tag state)) {
+        next unless exists $params{$t};
+        defined(my $p = $params{$t}) or next;
+        for my $a ('ARRAY' eq ref $p ? @$p : ($p)) {
+            push @{$fields{a}}, _encode_type($t => $a);
         }
     }
     # Remove a tag or state.
-    for my $t (qw( untag unstate )) {
-        next unless exists $params{ $t };
-        defined( my $p = $params{ $t } ) or next;
-        for my $d ( 'ARRAY' eq ref $p ? @$p : ( $p ) ) {
-            push @{ $fields{r} }, _encode_type( substr( $t, 2 ) => $d );
+    for my $t (qw(untag unstate)) {
+        next unless exists $params{$t};
+        defined(my $p = $params{$t}) or next;
+        for my $d ('ARRAY' eq ref $p ? @$p : ($p)) {
+            push @{$fields{r}}, _encode_type(substr($t, 2) => $d);
         }
     }
 
-    return $self->_edit( $url, %fields );
+    return $self->_edit($url, %fields);
 }
 
 sub tag_feed {
-    return shift->edit_feed( shift, tag => \@_ );
+    return shift->edit_feed(shift, tag => \@_);
 }
 
 sub untag_feed {
-    return shift->edit_feed( shift, untag => \@_ );
+    return shift->edit_feed(shift, untag => \@_);
 }
 
 sub state_feed {
-    return shift->edit_feed( shift, state => \@_ );
+    return shift->edit_feed(shift, state => \@_);
 }
 
 sub unstate_feed {
-    return shift->edit_feed( shift, unstate => \@_ );
+    return shift->edit_feed(shift, unstate => \@_);
 }
 
 sub subscribe {
-    return shift->edit_feed( \@_, subscribe => 1 );
+    return shift->edit_feed(\@_, subscribe => 1);
 }
 
 sub unsubscribe {
-    return shift->edit_feed( \@_, unsubscribe => 1 );
+    return shift->edit_feed(\@_, unsubscribe => 1);
 }
 
 sub rename_feed {
-    return $_[0]->edit_feed( $_[1], title => $_[2] );
+    return $_[0]->edit_feed($_[1], title => $_[2]);
 }
 
 sub mark_read_feed {
-    return shift->mark_read( feed => \@_ );
+    return shift->mark_read(feed => \@_);
 }
 
 ## Edit entries
@@ -348,73 +348,73 @@ sub edit_entry {
     $self->_login or return;
     $self->_token or return;
 
-    my %fields = ( ac => 'edit' );
-    for my $e ( 'ARRAY' eq ref $entry ? @$entry : ( $entry ) ) {
-        push @{ $fields{i} }, $e->id;
-        push @{ $fields{s} }, $e->stream_id;
+    my %fields = (ac => 'edit');
+    for my $e ('ARRAY' eq ref $entry ? @$entry : ($entry)) {
+        push @{$fields{i}}, $e->id;
+        push @{$fields{s}}, $e->stream_id;
     }
-    return 1 unless @{ $fields{i} || [] };
+    return 1 unless @{$fields{i} || []};
 
     my $url = EDIT_ENTRY_TAG_URL;
 
     # Add a tag or state.
-    for my $t (qw( tag state )) {
-        next unless exists $params{ $t };
-        defined( my $p = $params{ $t } ) or next;
-        for my $a ( 'ARRAY' eq ref $p ? @$p : ( $p ) ) {
-            push @{ $fields{a} }, _encode_type( $t => $a );
+    for my $t (qw(tag state)) {
+        next unless exists $params{$t};
+        defined(my $p = $params{$t}) or next;
+        for my $a ('ARRAY' eq ref $p ? @$p : ($p)) {
+            push @{$fields{a}}, _encode_type($t => $a);
         }
     }
     # Remove a tag or state.
-    for my $t (qw( untag unstate )) {
-        next unless exists $params{ $t };
-        defined( my $p = $params{ $t } ) or next;
-        for my $d ( 'ARRAY' eq ref $p ? @$p : ( $p ) ) {
-            push @{ $fields{r} }, _encode_type( substr( $t, 2 ) => $d );
+    for my $t (qw(untag unstate)) {
+        next unless exists $params{$t};
+        defined(my $p = $params{$t}) or next;
+        for my $d ('ARRAY' eq ref $p ? @$p : ($p)) {
+            push @{$fields{r}}, _encode_type(substr($t, 2) => $d);
         }
     }
 
-    return $self->_edit( $url, %fields );
+    return $self->_edit($url, %fields);
 }
 
 sub tag_entry {
-    return shift->edit_entry( shift, tag => \@_ );
+    return shift->edit_entry(shift, tag => \@_);
 }
 
 sub untag_entry {
-    return shift->edit_entry( shift, untag => \@_ );
+    return shift->edit_entry(shift, untag => \@_);
 }
 
 sub state_entry {
-    return shift->edit_entry( shift, state => \@_ );
+    return shift->edit_entry(shift, state => \@_);
 }
 
 sub unstate_entry {
-    return shift->edit_entry( shift, unstate => \@_ );
+    return shift->edit_entry(shift, unstate => \@_);
 }
 
 sub share_entry {
-    return shift->edit_entry( shift, state => 'broadcast' );
+    return shift->edit_entry(shift, state => 'broadcast');
 }
 
 sub unshare_entry {
-    return shift->edit_entry( shift, unstate => 'broadcast' );
+    return shift->edit_entry(shift, unstate => 'broadcast');
 }
 
 sub star_entry {
-    return shift->edit_entry( shift, state => 'starred' );
+    return shift->edit_entry(shift, state => 'starred');
 }
 
 *star = \&star_entry;
 
 sub unstar_entry {
-    return shift->edit_entry( shift, unstate => 'starred' );
+    return shift->edit_entry(shift, unstate => 'starred');
 }
 
 *unstar = \&unstar_entry;
 
 sub mark_read_entry {
-    return shift->edit_entry( \@_, state => 'read' );
+    return shift->edit_entry(\@_, state => 'read');
 }
 
 ## Miscellaneous
@@ -426,12 +426,12 @@ sub mark_read {
     $self->_token or return;
 
     my %fields;
-    my @types = grep { exists $params{ $_ } } qw( feed state tag );
+    my @types = grep { exists $params{$_} } qw(feed state tag);
     for my $type (@types) {
-        push @{ $fields{s} }, _encode_type( $type, $params{$type} );
+        push @{$fields{s}}, _encode_type($type, $params{$type});
     }
 
-    return $self->_edit( EDIT_MARK_READ_URL, %fields );
+    return $self->_edit(EDIT_MARK_READ_URL, %fields);
 }
 
 sub edit_preference {
@@ -440,7 +440,7 @@ sub edit_preference {
     $self->_login or return;
     $self->_token or return;
 
-    return $self->_edit( EDIT_PREF_URL, k => $key, v => $val );
+    return $self->_edit(EDIT_PREF_URL, k => $key, v => $val);
 }
 
 sub opml {
@@ -448,19 +448,19 @@ sub opml {
 
     $self->_login or return;
 
-    my $req = GET( EXPORT_SUBS_URL );
-    my $res = $self->_request( $req ) or return;
+    my $req = GET(EXPORT_SUBS_URL);
+    my $res = $self->_request($req) or return;
 
     return $res->decoded_content;
 }
 
 sub ping {
     my ($self, %fields) = @_;
-    my $res = $self->_request( GET( PING_URL ) ) or return;
+    my $res = $self->_request(GET(PING_URL)) or return;
 
     return 1 if 'OK' eq $res->decoded_content;
 
-    $self->error( 'Ping failed: '. $res->decoded_content );
+    $self->error('Ping failed: '. $res->decoded_content);
     return;
 }
 
@@ -470,10 +470,10 @@ sub ping {
 sub _login {
     my ($self, $force) = @_;
 
-    return if $self->_public;
+    return 1 if $self->_public;
     return 1 if not $force and $self->_cookie;
 
-    my $uri = URI->new( LOGIN_URL );
+    my $uri = URI->new(LOGIN_URL);
     $uri->query_form(
         service  => 'reader',
         Email    => $self->username,
@@ -481,18 +481,18 @@ sub _login {
         source   => $self->ua->agent,
         continue => READER_URL,
     );
-    my $res = $self->ua->post( $uri );
+    my $res = $self->ua->post($uri);
     my $content = $res->decoded_content;
-    if ( $res->is_error ) {
+    if ($res->is_error) {
         my ($err) = $content =~ m[ ^Error=(.*)$ ]mx;
-        $self->error( $res->status_line . ( $err ? (': '. $err) : '' ) );
+        $self->error($res->status_line . ($err ? (': '. $err) : ''));
 
         return;
     }
 
     my ($sid) = $content =~ m[ ^SID=(.*)$ ]mx;
     unless ($sid) {
-        $self->error( 'could not find SID value for cookie' );
+        $self->error('could not find SID value for cookie');
         return;
     }
 
@@ -509,34 +509,34 @@ sub _request {
     return if $count and 2 <= $count;
 
     # Assume all POST requests are secure.
-    $req->uri->scheme( $self->scheme ) if 'GET' eq $req->method;
-    $req->uri->query_param( ck => time * 1000 );
-    $req->uri->query_param( client => $self->ua->agent );
+    $req->uri->scheme($self->scheme) if 'GET' eq $req->method;
+    $req->uri->query_param(ck => time * 1000);
+    $req->uri->query_param(client => $self->ua->agent);
 
     print $req->as_string, "-"x80, "\n" if DEBUG;
 
-    if ( HAS_ZLIB ) {
-        $req->header( accept_encoding => 'gzip,deflate' );
+    if (HAS_ZLIB) {
+        $req->header(accept_encoding => 'gzip,deflate');
         # Doesn't always work; gets 415- unsupported media type for some urls.
-        #if ( my $content = $req->content ) {
-        #    if ( $content = Compress::Zlib::memGzip( $content ) ) {
-        #        $req->content( $content );
-        #        $req->content_length( length $content );
-        #        $req->content_encoding( 'gzip' );
+        #if (my $content = $req->content) {
+        #    if ($content = Compress::Zlib::memGzip($content)) {
+        #        $req->content($content);
+        #        $req->content_length(length $content);
+        #        $req->content_encoding('gzip');
         #    }
         #}
     }
 
-    my $res = $self->ua->request( $req );
-    if ( $res->is_error ) {
+    my $res = $self->ua->request($req);
+    if ($res->is_error) {
         # Need a fresh token.
-        if ( $res->header( 'X-Reader-Google-Bad-Token' ) ) {
+        if ($res->header('X-Reader-Google-Bad-Token')) {
             print "Stale token- retrying\n" if DEBUG;
-            $self->_token( 1 ) or return;
-            return $self->_request( $req,  $count++ );
+            $self->_token(1) or return;
+            return $self->_request($req,  $count++);
         }
 
-        $self->error( $res->status_line . ' - ' . $res->decoded_content );
+        $self->error($res->status_line . ' - ' . $res->decoded_content);
         return;
     }
 
@@ -551,10 +551,10 @@ sub _token {
 
     $self->_login or return;
 
-    my $uri = URI->new( TOKEN_URL, 'https' );
-    my $res = $self->_request( GET( $uri ) ) or return;
+    my $uri = URI->new(TOKEN_URL, 'https');
+    my $res = $self->_request(GET($uri)) or return;
 
-    return $self->token( $res->decoded_content );
+    return $self->token($res->decoded_content);
 }
 
 sub _public {
@@ -570,17 +570,17 @@ sub _encode_type {
     my ($type, $val, $escape) = @_;
     my @paths;
 
-    if ( 'feed' eq $type ) {
-        @paths = _encode_feed( $val, $escape);
+    if ('feed' eq $type) {
+        @paths = _encode_feed($val, $escape);
     }
-    elsif ( 'tag' eq $type ) {
-        @paths = _encode_tag( $val );
+    elsif ('tag' eq $type) {
+        @paths = _encode_tag($val);
     }
-    elsif ( 'state' eq $type ) {
-        @paths = _encode_state( $val );
+    elsif ('state' eq $type) {
+        @paths = _encode_state($val);
     }
-    elsif ( 'entry' eq $type ) {
-        @paths = _encode_entry( $val );
+    elsif ('entry' eq $type) {
+        @paths = _encode_entry($val);
     }
     else {
         return;
@@ -593,10 +593,10 @@ sub _encode_feed {
     my ($feed, $escape) = @_;
 
     my @paths;
-    for my $f ( 'ARRAY' eq ref $feed ? @$feed : ( $feed ) ) {
+    for my $f ('ARRAY' eq ref $feed ? @$feed : ($feed)) {
         my $path = $f;
-        if ( 'feed/' ne substr $f, 0, 5 ) {
-            $path = 'feed/' . $escape ? uri_escape( $f ) : $f;
+        if ('feed/' ne substr $f, 0, 5) {
+            $path = 'feed/' . ($escape ? uri_escape($f) : $f);
         }
         push @paths, $path;
     }
@@ -608,9 +608,9 @@ sub _encode_tag {
     my ($tag) = @_;
 
     my @paths;
-    for my $t ( 'ARRAY' eq ref $tag ? @$tag : ( $tag ) ) {
+    for my $t ('ARRAY' eq ref $tag ? @$tag : ($tag)) {
         my $path = $t;
-        if ( $t !~ m[ ^user/(?:-|\d{20})/ ]x ) {
+        if ($t !~ m[ ^user/(?:-|\d{20})/ ]x) {
             $path = "user/-/label/$t"
         }
         push @paths, $path;
@@ -623,9 +623,9 @@ sub _encode_state {
     my ($state) = @_;
 
     my @paths;
-    for my $s ( 'ARRAY' eq ref $state ? @$state : ( $state ) ) {
+    for my $s ('ARRAY' eq ref $state ? @$state : ($state)) {
         my $path = $s;
-        if ( $s !~ m[ ^user/(?:-|\d{20})/ ]x ) {
+        if ($s !~ m[ ^user/(?:-|\d{20})/ ]x) {
             $path = "user/-/state/com.google/$s";
         }
         push @paths, $path;
@@ -638,9 +638,9 @@ sub _encode_entry {
     my ($entry) = @_;
 
     my @paths;
-    for my $e ( 'ARRAY' eq ref $entry ? @$entry : ( $entry ) ) {
+    for my $e ('ARRAY' eq ref $entry ? @$entry : ($entry)) {
         my $path = $e;
-        if ( 'tag:google.com,2005:reader/item/' ne substr $e, 0, 32 ) {
+        if ('tag:google.com,2005:reader/item/' ne substr $e, 0, 32) {
             $path = "tag:google.com,2005:reader/item/$e";
         }
         push @paths, $path;
@@ -655,35 +655,35 @@ sub _feed {
     $self->_login or return;
 
     my $path = $self->_public ? ATOM_PUBLIC_URL : ATOM_URL;
-    my $uri = URI->new( $path . _encode_type( $type, $val, 1 ) );
+    my $uri = URI->new($path . _encode_type($type, $val, 1));
 
     my %fields;
-    if ( my $count = $params{count} ) {
+    if (my $count = $params{count}) {
         $fields{n} = $count;
     }
-    if ( my $start_time = $params{start_time} ) {
+    if (my $start_time = $params{start_time}) {
         $fields{ot} = $start_time;
     }
-    if ( my $order = $params{order} || $params{sort} ) {
+    if (my $order = $params{order} || $params{sort}) {
             # m = magic/auto; not really sure what that is
             $fields{r} = 'desc' eq $order ? 'n' :
                          'asc' eq $order ? 'o' : $order;
     }
-    if ( defined( my $continuation = $params{continuation} ) ) {
+    if (defined(my $continuation = $params{continuation})) {
         $fields{c} = $continuation;
     }
-    if ( my $ex = $params{exclude} ) {
-        for my $x ( 'ARRAY' eq ref $ex ? @$ex : ( $ex ) ) {
-            while ( my ($xtype, $exclude) = each %$x ) {
-                push @{ $fields{xt} }, _encode_type( $xtype, $exclude );
+    if (my $ex = $params{exclude}) {
+        for my $x ('ARRAY' eq ref $ex ? @$ex : ($ex)) {
+            while (my ($xtype, $exclude) = each %$x) {
+                push @{$fields{xt}}, _encode_type($xtype, $exclude);
             }
         }
     }
 
-    $uri->query_form( \%fields );
+    $uri->query_form(\%fields);
 
-    my $feed = ( __PACKAGE__.'::Feed' )->new( request => GET( $uri ) );
-    return $self->more( $feed );
+    my $feed = (__PACKAGE__.'::Feed')->new(request => GET($uri));
+    return $self->more($feed);
 }
 
 sub _list {
@@ -691,22 +691,22 @@ sub _list {
 
     $self->_login or return;
 
-    my $uri = URI->new( $url );
-    $uri->query_form( { $uri->query_form, output => 'json' } );
+    my $uri = URI->new($url);
+    $uri->query_form({ $uri->query_form, output => 'json' });
 
-    my $res = $self->_request( GET( $uri ) ) or return;
+    my $res = $self->_request(GET($uri)) or return;
 
-    my $ref = eval { JSON::Any->decode( $res->decoded_content ) };
-    if ( $@ ) {
-       $self->error( "Failed to parse JSON response: $@" );
+    my $ref = eval { JSON::Any->decode($res->decoded_content) };
+    if ($@) {
+       $self->error("Failed to parse JSON response: $@");
         return;
     }
 
     # Remove an unecessary level of indirection.
-    my $aref = ( grep { 'ARRAY' eq ref } values %$ref )[0] || [];
+    my $aref = (grep { 'ARRAY' eq ref } values %$ref)[0] || [];
 
-    for my $ref ( @$aref ) {
-        $ref = ( __PACKAGE__.'::ListElement' )->new( $ref )
+    for my $ref (@$aref) {
+        $ref = (__PACKAGE__.'::ListElement')->new($ref)
     }
 
     return @$aref
@@ -714,14 +714,14 @@ sub _list {
 
 sub _edit {
     my ($self, $url, %fields) = @_;
-    my $uri = URI->new( $url, 'https' );
-    my $req = POST( $uri, [ %fields, T => $self->token ] );
-    my $res = $self->_request( $req ) or return;
+    my $uri = URI->new($url, 'https');
+    my $req = POST($uri, [ %fields, T => $self->token ]);
+    my $res = $self->_request($req) or return;
 
     return 1 if 'OK' eq $res->decoded_content;
 
     # TODO: is there a standard error format which can be reliably parsed?
-    $self->error( 'Edit failed: '. $res->decoded_content );
+    $self->error('Edit failed: '. $res->decoded_content);
     return;
 }
 
@@ -732,28 +732,28 @@ sub _edit_tag {
     $self->_token or return;
 
     my %fields;
-    push @{ $fields{s} }, _encode_type( $type => $tag );
-    return 1 unless @{ $fields{s} || [] };
+    push @{$fields{s}}, _encode_type($type => $tag);
+    return 1 unless @{$fields{s} || []};
 
     my $url;
-    if ( grep { exists $params{ $_ } } qw( share public ) ) {
+    if (grep { exists $params{$_} } qw(share public)) {
         $url = EDIT_TAG_SHARE_URL;
         $fields{pub} = 'true';
     }
-    elsif ( grep { exists $params{ $_ } } qw( unshare private ) ) {
+    elsif (grep { exists $params{$_} } qw(unshare private)) {
         $url = EDIT_TAG_SHARE_URL;
         $fields{pub} = 'false';
     }
-    elsif ( grep { exists $params{ $_ } } qw( disable delete ) ) {
+    elsif (grep { exists $params{$_} } qw(disable delete)) {
         $url = EDIT_TAG_DISABLE_URL;
         $fields{ac} = 'disable-tags';
     }
     else {
-        $self->error( 'Unknown action' );
+        $self->error('Unknown action');
         return;
     }
 
-    return $self->_edit( $url, %fields );
+    return $self->_edit($url, %fields);
 }
 
 sub _states {
@@ -781,11 +781,11 @@ WebService::Google::Reader - Perl interface to Google Reader
         password => $pass,
     );
 
-    my $feed = $reader->unread( count => 100 );
+    my $feed = $reader->unread(count => 100);
     my @entries = $feed->entries;
 
     # Fetch past entries.
-    while ( $reader->more( $feed ) ) {
+    while ($reader->more($feed)) {
         my @entries = $feed->entries;
     }
 
@@ -847,7 +847,7 @@ default order has no limitation.
 
 Request entries only newer than this time (represented as a unix timestamp).
 
-=item B<exclude>( feed => $feed|[@feeds], tag => $tag|[@tags] )
+=item B<exclude>(feed => $feed|[@feeds], tag => $tag|[@tags])
 
 Accepts a hash reference to one or more of feed / tag / state. Each of which
 is a scalar or array reference.
@@ -858,35 +858,35 @@ is a scalar or array reference.
 
 =over
 
-=item B<feed>( $feed )
+=item B<feed>($feed)
 
 Accepts a single feed url.
 
-=item B<tag>( $tag )
+=item B<tag>($tag)
 
 Accepts a single tag name. See L</TAGS>
 
-=item B<state>( $state )
+=item B<state>($state)
 
 Accepts a single state name. See L</STATES>.
 
 =item B<shared>
 
-Shortcut for B<state>( 'broadcast' ).
+Shortcut for B<state>('broadcast').
 
 =item B<starred>
 
-Shortcut for B<state>( 'starred' ).
+Shortcut for B<state>('starred').
 
 =item B<unread>
 
-Shortcut for B<state>( 'reading-list', exclude => { state => 'read' } )
+Shortcut for B<state>('reading-list', exclude => { state => 'read' })
 
 =back
 
 =over
 
-=item B<search>( $query, %params )
+=item B<search>($query, %params)
 
 Accepts a query string and the following named parameters:
 
@@ -960,7 +960,7 @@ The following methods are used to edit feed subscriptions.
 
 =over
 
-=item B<edit_feed>( $feed|[@feeds], %params )
+=item B<edit_feed>($feed|[@feeds], %params)
 
 Requires a feed url or Feed object, or a reference to a list of them.
 The following named parameters are accepted:
@@ -985,27 +985,27 @@ associate / unassociate the target feeds.
 
 =back
 
-=item B<tag_feed>( $feed|[@feeds], @tags )
+=item B<tag_feed>($feed|[@feeds], @tags)
 
-=item B<untag_feed>( $feed|[@feeds], @tags )
+=item B<untag_feed>($feed|[@feeds], @tags)
 
-=item B<state_feed>( $feed|[@feeds], @states )
+=item B<state_feed>($feed|[@feeds], @states)
 
-=item B<unstate_feed>( $feed|[@feeds], @states )
+=item B<unstate_feed>($feed|[@feeds], @states)
 
 Associate / unassociate a list of tags / states from a feed / feeds.
 
-=item B<subscribe>( @feeds )
+=item B<subscribe>(@feeds)
 
-=item B<unsubscribe>( @feeds )
+=item B<unsubscribe>(@feeds)
 
 Subscribe or unsubscribe from a list of feeds.
 
-=item B<rename_feed>( $feed|[@feeds], $title )
+=item B<rename_feed>($feed|[@feeds], $title)
 
 Renames a feed to the given title.
 
-=item B<mark_read_feed>( @feeds )
+=item B<mark_read_feed>(@feeds)
 
 Marks the feeds as read.
 
@@ -1017,9 +1017,9 @@ The following methods are used to edit tags and states.
 
 =over
 
-=item B<edit_tag>( $tag|[@tags], %params )
+=item B<edit_tag>($tag|[@tags], %params)
 
-=item B<edit_state>( $state|[@states], %params )
+=item B<edit_state>($state|[@states], %params)
 
 Accepts the following parameters.
 
@@ -1039,35 +1039,35 @@ Only tags (and not states) can be disabled.
 
 =back
 
-=item B<share_tag>( @tags )
+=item B<share_tag>(@tags)
 
-=item B<unshare_tag>( @tags )
+=item B<unshare_tag>(@tags)
 
-=item B<share_state>( @states )
+=item B<share_state>(@states)
 
-=item B<unshare_state>( @states )
+=item B<unshare_state>(@states)
 
 Associate / unassociate the 'broadcast' state with the given tags / states.
 
-=item B<delete_tag>( @tags )
+=item B<delete_tag>(@tags)
 
 Delete the given tags.
 
-=item B<rename_feed_tag>( $oldtag|[@oldtags], $newtag|[@newtags]
+=item B<rename_feed_tag>($oldtag|[@oldtags], $newtag|[@newtags]
 
 Renames the tags associated with any feeds.
 
-=item B<rename_entry_tag>( $oldtag|[@oldtags], $newtag|[@newtags]
+=item B<rename_entry_tag>($oldtag|[@oldtags], $newtag|[@newtags]
 
 Renames the tags associated with any individual entries.
 
-=item B<rename_tag>( $oldtag|[@oldtags], $newtag|[@newtags]
+=item B<rename_tag>($oldtag|[@oldtags], $newtag|[@newtags]
 
 Calls B<rename_feed_tag> and B<rename_entry_tag>, and finally B<delete_tag>.
 
-=item B<mark_read_tag>( @tags )
+=item B<mark_read_tag>(@tags)
 
-=item B<mark_read_state>( @states )
+=item B<mark_read_state>(@states)
 
 Marks all entries as read for the given tags / states.
 
@@ -1079,7 +1079,7 @@ The following methods are used to edit individual entries.
 
 =over
 
-=item B<edit_entry>( $entry|[@entries], %params )
+=item B<edit_entry>($entry|[@entries], %params)
 
 =over
 
@@ -1089,19 +1089,19 @@ Associate / unassociate the entries with the given tags / states.
 
 =back
 
-=item B<tag_entry>( $entry|[@entries], @tags )
+=item B<tag_entry>($entry|[@entries], @tags)
 
-=item B<untag_entry>( $entry|[@entries], @tags )
+=item B<untag_entry>($entry|[@entries], @tags)
 
-=item B<state_entry>( $entry|[@entries], @tags )
+=item B<state_entry>($entry|[@entries], @tags)
 
-=item B<unstate_entry>( $entry|[@entries], @tags )
+=item B<unstate_entry>($entry|[@entries], @tags)
 
 Associate / unassociate the entries with the given tags / states.
 
-=item B<share_entry>( @entries )
+=item B<share_entry>(@entries)
 
-=item B<unshare_entry>( @entries )
+=item B<unshare_entry>(@entries)
 
 Marks all the given entries as "broadcast".
 
@@ -1115,7 +1115,7 @@ Marks all the given entries as "broadcast".
 
 Marks / unmarks all the given entries as "starred".
 
-=item B<mark_read_entry>( @entries )
+=item B<mark_read_entry>(@entries)
 
 Marks all the given entries as "read".
 
@@ -1127,12 +1127,12 @@ These are a list of other useful methods.
 
 =over
 
-=item B<edit_preference>( $key, $value )
+=item B<edit_preference>($key, $value)
 
 Sets the given preference name to the given value.
 
-=item B<mark_read>( feed => $feed|[@feeds], state => $state|[@states],
-                    tag => $tag|[@tags] )
+=item B<mark_read>(feed => $feed|[@feeds], state => $state|[@states],
+                    tag => $tag|[@tags])
 
 =item B<opml>
 
